__version__ = '1.1.6'
__title__ = 'openapi3-parser'
__author__ = 'Artem Manchenkov'
__email__ = 'artem@manchenkoff.me'
__description__ = 'OpenAPI v3 parser'

from .parser import parse

__all__ = [
    "parse"
]
